@@ -72,12 +72,12 @@ fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
     )
 }
 
-#[test_case(MarketType::Spot, "BTCUSDT")]
+#[test_case(MarketType::Spot, "BTCUSDT"; "inconclusive since spot market has too many symbols")]
 #[test_case(MarketType::InverseFuture, "BTCUSD_211231")]
 #[test_case(MarketType::LinearFuture, "BTCUSDT_211231")]
 #[test_case(MarketType::InverseSwap, "BTCUSD_PERP")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
-#[test_case(MarketType::EuropeanOption, "BTC-210129-40000-C"; "inconclusive")]
+#[test_case(MarketType::EuropeanOption, "BTC-210129-40000-C"; "inconclusive since option market has too many symbols")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
     test_one_symbol!(
         crawl_l2_snapshot,
